@@ -59,4 +59,15 @@ public:
     QObject *guiObject);
 };
 
+
+class ADBSTB6: public PIRKeysetMetaData
+{
+public:
+  ADBSTB6(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 #endif // ADB_H
