@@ -9,32 +9,40 @@ class MagnavoxDVD1: public PIRKeysetMetaData
 {
 public:
   MagnavoxDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class MagnavoxVCR1: public PIRKeysetMetaData
 {
 public:
   MagnavoxVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class MagnavoxConverterBox1: public PIRKeysetMetaData
 {
 public:
   MagnavoxConverterBox1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class MagnavoxTV1: public PIRKeysetMetaData
 {
 public:
   MagnavoxTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // MAGNAVOX_H
