@@ -6,6 +6,7 @@
 #include "pirkeynames.h"
 #include "pirpanelnames.h"
 #include "pirmodprobe.h"
+#include "piracstateinfo.h"
 
 class QListWidget;
 class QListWidgetItem;
@@ -58,6 +59,10 @@ public:
     PIRKeyName name,
     unsigned int keysetID);
 
+  bool startRepeating(
+    PIRACStateInfo state,
+    PIRKeyName name);
+
   void stopRepeating();
 
   // Favorites panel actions:
@@ -156,6 +161,11 @@ signals:
     unsigned int keysetID,
     PIRKeyName name);
 
+  void buttonPressed(
+    PIRACStateInfo state,
+    unsigned int keysetID,
+    PIRKeyName name);
+
   void buttonReleased();
 
 public slots:
