@@ -707,6 +707,7 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new SamsungDVD1b(++counter));
   setupKeyset(new SamsungDVD2(++counter));
   setupKeyset(new SamsungAC1(++counter));
+  setupKeyset(new SamsungAC2(++counter));
   setupKeyset(new SamsungDVBT1(++counter));
 
   setupKeyset(new SanyoVCR1(++counter));
@@ -1082,6 +1083,27 @@ void PIRKeysetManager::setDutyCycle(
 }
 
 
+const PIRACKeyset *PIRKeysetManager::getACKeyset(
+  unsigned int keysetID) const
+{
+  PIRKeysetCollection::const_iterator i = keysetsInfo.find(keysetID);
+
+  if (i == keysetsInfo.end())
+  {
+    return NULL;
+  }
+
+  const PIRKeysetMetaData *meta = i->second;
+
+  if (!meta)
+  {
+    return NULL;
+  }
+
+  return (dynamic_cast<const PIRACKeyset *>(meta));
+}
+
+
 bool PIRKeysetManager::clearKeyset(
   unsigned int keysetID)
 {
