@@ -9,6 +9,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[ADB_Make] = "ADB";
   makes[Admiral_Make] = "Admiral";
   makes[Aiwa_Make] = "Aiwa";
+  makes[Alpine_Make] = "Alpine";
   makes[Anitech_Make] = "Anitech";
   makes[AOC_Make] = "AOC";
   makes[Apple_Make] = "Apple";
@@ -59,6 +60,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Huawei_Make] = "Huawei";
   makes[Humax_Make] = "Humax";
   makes[Hyundai_Make] = "Hyundai";
+  makes[ILO_Make] = "ILO";
   makes[IRobot_Make] = "iRobot";
   makes[JVC_Make] = "JVC";
   makes[Kaon_Make] = "Kaon";
@@ -101,12 +103,14 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Roku_Make] = "Roku";
   makes[Saba_Make] = "Saba";
   makes[Sagem_Make] = "Sagem";
+  makes[Sagemcom_Make] = "Sagemcom";
   makes[Samsung_Make] = "Samsung";
   makes[Sanyo_Make] = "Sanyo";
   makes[Sharp_Make] = "Sharp";
   makes[Sinotec_Make] = "Sinotec";
   makes[Sky_Make] = "Sky";
   makes[Sony_Make] = "Sony";
+  makes[Starhub_Make] = "Starhub";
   makes[Starsat_Make] = "Starsat";
   makes[Strong_Make] = "Strong";
   makes[Sylvania_Make] = "Sylvania";
